package com.jjt.inventory.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.jjt.inventory.domain.TwinCalcDayBp;

import java.util.List;

/**
 * 白坯库日统计数据Mapper接口
 *
 * @author wukai
 * @date 2025-06-13
 */
public interface TwinCalcDayBpMapper extends BaseMapper<TwinCalcDayBp> {
    /**
     * 查询白坯库日统计数据
     *
     * @param id 白坯库日统计数据主键
     * @return 白坯库日统计数据
     */
    public TwinCalcDayBp selectTwinCalcDayBpById(Long id);

    /**
     * 查询白坯库日统计数据列表
     *
     * @param twinCalcDayBp 白坯库日统计数据
     * @return 白坯库日统计数据集合
     */
    public List<TwinCalcDayBp> selectTwinCalcDayBpList(TwinCalcDayBp twinCalcDayBp);

    /**
     * 新增白坯库日统计数据
     *
     * @param twinCalcDayBp 白坯库日统计数据
     * @return 结果
     */
    public int insertTwinCalcDayBp(TwinCalcDayBp twinCalcDayBp);

    /**
     * 修改白坯库日统计数据
     *
     * @param twinCalcDayBp 白坯库日统计数据
     * @return 结果
     */
    public int updateTwinCalcDayBp(TwinCalcDayBp twinCalcDayBp);

    /**
     * 删除白坯库日统计数据
     *
     * @param id 白坯库日统计数据主键
     * @return 结果
     */
    public int deleteTwinCalcDayBpById(Long id);

    /**
     * 批量删除白坯库日统计数据
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTwinCalcDayBpByIds(Long[] ids);

    /**
     * 删除白坯库日统计数据信息
     *
     * @param date 白坯库日统计数据主键
     */
    void delete4date(String date);
}
